from django.contrib import admin

from swap_user.admin import BaseUserAdmin
from swap_user.to_named_email.forms import (
    NamedUserEmailOptionalFieldsForm,
    NamedUserEmailRequiredFieldsForm,
)
from swap_user.to_named_email.models import NamedEmailUser


class NamedEmailUserAdmin(BaseUserAdmin):
    add_form_class = NamedUserEmailRequiredFieldsForm
    change_form_class = NamedUserEmailOptionalFieldsForm


admin.site.register(NamedEmailUser, NamedEmailUserAdmin)



from swap_user.to_phone_otp.base_models import AbstractPhoneOTPUser


class PhoneOTPUser(AbstractPhoneOTPUser):
    """
    Concrete implementation of user with phone login.
    """

    class Meta:
        swappable = "AUTH_USER_MODEL"
        verbose_name = "OTP phone user"
        verbose_name_plural = "OTP phone users"



from swap_user.forms import BaseUserOptionalFieldsForm, BaseUserRequiredFieldsForm
from swap_user.to_named_email.models import NamedEmailUser


class NamedUserEmailOptionalFieldsForm(BaseUserOptionalFieldsForm):
    """
    Form for - NamedEmailUser model.
    With required `password_1` and `password_2` fields.
    """

    class Meta(BaseUserOptionalFieldsForm.Meta):
        model = NamedEmailUser


class NamedUserEmailRequiredFieldsForm(BaseUserRequiredFieldsForm):
    """
    Form for - NamedEmailUser model.
    With required `password_1` and `password_2` fields.
    """

    class Meta(BaseUserRequiredFieldsForm.Meta):
        model = NamedEmailUser
